# -*- coding: utf-8 -*-
"""
Created on Thu Mar  7 09:42:04 2024

@author: vlandgraf
"""

# Import necessary libraries
import gemdat 
from pathlib import Path
from gemdat import SitesData, Trajectory, plots, simulation_metrics
from gemdat import transitions
from gemdat.io import load_known_material
from pymatgen.io.vasp import Vasprun, Poscar
import general_AF_structure_analysis
import pickle as pkl
import numpy as np
import matplotlib.pyplot as plt 
import os
import glob
import copy
import random
import math
from itertools import combinations

# Define the dictionary of trajectories with the example of LSN72
#Data can slo be obtained from the vasprun file directly in that case: gemdat.trajectory.Trajectory.from_vasprun('vasprun.xml')
dict_of_trajectories = {72: gemdat.trajectory.Trajectory.from_cache('vasprun.xml.69adc856.cache')}

# Define the length of AIMD partitions
value = 1E-13 #s

#Split the directory into different parts so that cumulative jumps as a funcition of time can be otbained
for k, v in dict_of_trajectories.items():
    # Get the initial structure from the trajectory
    s = v.get_structure(0)
    
    # Modify the structure to fill the Li-lattice with Li, just a formality to indicate where potential site positions
	#are in the jump analysis
    s = general_AF_structure_analysis.get_structure_with_all_Li(s)
    
    # Calculate the number of parts to divide the AIMD into
    part_into = int(len(v) * 2E-15 / value)
    
    # Create a SitesData object to analyze transitions
    sites = SitesData(
        structure=s,
        trajectory=v,
        floating_specie='Li',
        n_parts=part_into
    )
    
    # Calculate total jumps and prepare data for plotting
    total_jumps = len(sites.transitions.events)
    cumulative_jumps = [np.sum(sites.transitions_parts[:i + 1]) for i in range(len(sites.transitions_parts))]
    
    # Create the plot
    plt.figure(figsize=(3.25, 3.25 * 3 / 3), dpi=400)
	time = np.array(range(len(sites.transitions_parts))) * 2 / 3 * value / 1E-12
    plt.plot(time, cumulative_jumps)
    
    # Set plot labels and parameters
    plt.xlabel('Simulation time (ps)', size=10)
    plt.ylabel('Cumulative jump events', size=10)
    plt.tick_params(which='both', axis='both', direction='in', labelsize=10)

    # Display the plot
    plt.show()
